# POST Request Testing

## Introduction

Use [Gambio\Dragger\Domain\Testing\Api\TestCase\PostTestCase](../../src/Domain/Testing/Api/TestCase/PostTestCase.php) for get
endpoints.  
Because post requests usually interacts with some kind of data, it is required to override ::initialFixture.

The method ::assertDataSetAdded needs instead of the test configuration object an instance of
[PostTestVerification](../../src/Domain/Testing/Api/Verification/Post/PostTestVerification.php). The information
will be used to verify that new data was added into the storage.

### Example

```php
class MyPostTest extends PostTestCase
{
    public function testCategoriesPostEndpointsAddsNewData() : void
    {
        $sut      = __DIR__ . '/../../../docs/REST/swagger/api/categories/post_categories.yml';
        $endpoint = $this->endpointFrom($sut);
        
        $affectedTables = PostAffectedTables::create();
        $affectedTables->add('categories', 1);
        $affectedTables->add('categories_description', 2);
        $verification = PostTestVerification::create($endpoint, $affectedTables, 3);
        
        $this->assertDataSetAdded($verification);
    }
    
    
    /**
     * @return Fixture|null
     */
    protected function initialFixture() : ?Fixture
    {
        return Fixture::fromFile(__DIR__ . '/fixtures/SimpleProductsAndCategoriesDataSet.php');
    }
}
```
