# PUT Request Testing

## Introduction

Use [Gambio\Dragger\Domain\Testing\Api\TestCase\PutTestCase](../../src/Domain/Testing/Api/TestCase/PutTestCase.php) for get
endpoints.  
Because put requests usually interacts with some kind of data, it is required to override ::initialFixture.

The method ::assertPutRequest needs instead of the test configuration object an instance of
[PutTestVerification](../../src/Domain/Testing/Api/Verification/Put/PutTestVerification.php). The information 
will be used to verify that existing data was changed in the storage.

### [PutTestVerification](../../src/Domain/Testing/Api/Verification/Put/PutTestVerification.php)
Usually, put requests either update a single entity by using the id provided in url path or updating a list of
entities (bulk) by using ids provided in request body.  
There are factory methods for both approaches (::viaPathId, ::viaRequestBody). Depending of the used approach,
different additional params are needed.
Afterwards, it is possible to add expectations to the verification. These ensure that, in case of put, data sets
changed.

### Example

```php
class MyPutTest extends DeleteTestCase
{
    public function testPutRequestWithIdInPath() : void
    {
        $endpoint       = $this->endpointFrom(
            __DIR__ . '/../../gxdev/docs/REST/swagger/api/categories/put_categories_(id).yml'
        );
        $identifier     = 'id';
        $pathIdentifier = ['category_id' => 2];
        $verification   = PutTestVerification::viaPathId($endpoint, $identifier, $pathIdentifier);
        
        $verification->add(
            Expect::changed('categories', ['categories_id' => 2]),
            Expect::changed('categories_description', ['categories_id' => 2])
        );
        
        $this->assertPutRequest($verification);
    }
     
     
     public function testPutRequestWithIdInBody() : void
     {
         $endpoint     = $this->endpointFrom(
             __DIR__ . '/../../gxdev/docs/REST/swagger/api/categories/put_categories.yml'
         );
         $identifier   = 'id';
         $verification = PutTestVerification::viaRequestBody($endpoint, $identifier, 2, 3, 4);
         
         $verification->add(
             Expect::changed('categories', ['categories_id' => 2]),
             Expect::changed('categories_description', ['categories_id' => 2]),
             Expect::changed('categories', ['categories_id' => 3]),
             Expect::changed('categories_description', ['categories_id' => 3]),
             Expect::changed('categories', ['categories_id' => 4]),
             Expect::changed('categories_description', ['categories_id' => 4])
         );
         
         $this->assertPutRequest($verification);
     }
     
     
     protected function initialFixture() : ?Fixture
     {
         return Fixture::fromFile(__DIR__ . '/SimpleProductsAndCategoriesDataSet.php');
     }
}
```
