<?php
/* --------------------------------------------------------------
 MyPutTest.php 2019-09-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

use Gambio\Dragger\Domain\DbFixture\Fixture;
use Gambio\Dragger\Domain\Testing\Api\Configuration\RequestConfiguration;
use Gambio\Dragger\Domain\Testing\Api\TestCase\PutTestCase;
use Gambio\Dragger\Domain\Testing\Api\Verification\Put\Expect;
use Gambio\Dragger\Domain\Testing\Api\Verification\Put\PutTestVerification;

class MyPutTest extends PutTestCase
{
    public function testPutRequestWithIdInPath() : void
    {
        $endpoint       = $this->endpointFrom(
            __DIR__ . '/../../gxdev/docs/REST/swagger/api/categories/put_categories_(id).yml'
        );
        $identifier     = 'id';
        $pathIdentifier = ['category_id' => 2];
        $verification   = PutTestVerification::viaPathId($endpoint, $identifier, $pathIdentifier);
        
        $verification->add(
            Expect::changed('categories', ['categories_id' => 2]),
            Expect::changed('categories_description', ['categories_id' => 2])
        );
        
        $this->assertPutRequest($verification);
    }
    
    
    public function testPutRequestWithIdInBody() : void
    {
        $endpoint     = $this->endpointFrom(
            __DIR__ . '/../../gxdev/docs/REST/swagger/api/categories/put_categories.yml'
        );
        $identifier   = 'id';
        $verification = PutTestVerification::viaRequestBody($endpoint, $identifier, 2, 3, 4);
        
        $verification->add(
            Expect::changed('categories', ['categories_id' => 2]),
            Expect::changed('categories_description', ['categories_id' => 2]),
            Expect::changed('categories', ['categories_id' => 3]),
            Expect::changed('categories_description', ['categories_id' => 3]),
            Expect::changed('categories', ['categories_id' => 4]),
            Expect::changed('categories_description', ['categories_id' => 4])
        );
        
        $this->assertPutRequest($verification);
    }
    
    
    protected function initialFixture() : ?Fixture
    {
        return Fixture::fromFile(__DIR__ . '/SimpleProductsAndCategoriesDataSet.php');
    }
    
    
    /**
     * Returns the request configuration.
     * The configuration contains request related data, like base url.
     *
     * @return RequestConfiguration
     */
    protected function requestConfiguration() : RequestConfiguration
    {
        // TODO: Implement requestConfiguration() method.
    }
    
    
    /**
     * Returns the path to the definitions/ directory.
     * The definitions/ directory contains all referenced files.
     *
     * @return string
     */
    protected function definitionsPath() : string
    {
        // TODO: Implement definitionsPath() method.
    }
}