<?php
/* --------------------------------------------------------------
 GxInstallerServiceProvider.php 2019-06-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Application\Provider;

use Gambio\Dragger\Domain\Commands\Sql\Service as SqlService;
use Gambio\Dragger\Domain\GxInstaller\Service;
use Gambio\Dragger\Domain\GxInstaller\Steps\CreateAccount;
use Gambio\Dragger\Domain\GxInstaller\Steps\InstallDb;
use Gambio\Dragger\Domain\GxInstaller\Steps\SetupShop;
use Gambio\Dragger\Domain\GxInstaller\Steps\WriteConfig;
use League\Container\Container;
use League\Container\ServiceProvider\AbstractServiceProvider;
use PDO;

/**
 * Class GxInstallerServiceProvider
 * @package Gambio\Dragger\Application\Provider
 *
 * @property-read Container $container
 */
class GxInstallerServiceProvider extends AbstractServiceProvider
{
    /**
     * @var array
     */
    protected $provides = [
        Service::class
    ];
    
    
    /**
     * Use the register method to register items with the container via the
     * protected $this->container property or the `getContainer` method
     * from the ContainerAwareTrait.
     *
     * @return void
     */
    public function register() : void
    {
        $this->container->add(Service::class)->addArguments(
            [
                InstallDb::class,
                WriteConfig::class,
                CreateAccount::class,
                SetupShop::class
            ]
        );
        $this->container->add(InstallDb::class)->addArgument(SqlService::class);
        $this->container->add(WriteConfig::class);
        $this->container->add(CreateAccount::class)->addArgument(PDO::class);
        $this->container->add(SetupShop::class)->addArgument(PDO::class);
    }
    
    
    /**
     * Setup required service providers.
     *
     * @param Container $container
     */
    public static function setup(Container $container) : void
    {
        $container->addServiceProvider(PdoServiceProvider::class);
        $container->addServiceProvider(SqlRunnerServiceProvider::class);
        $container->addServiceProvider(self::class);
    }
}