<?php
/* --------------------------------------------------------------
 GxTestConfiguration.php 2019-06-14
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Commands\GxTestConfiguration;

use Gambio\Dragger\Contracts\Configuration\DbCredentials;

/**
 * Class GxTestConfiguration
 * @package Gambio\Dragger\Domain\Commands\GxTestConfiguration
 */
class GxTestConfiguration
{
    /**
     * @var string
     */
    private $url;
    
    /**
     * @var string
     */
    private $admin;
    
    /**
     * @var string
     */
    private $pw;
    
    /**
     * @var DbCredentials
     */
    private $dbCredentials;
    
    
    /**
     * TestConfiguration constructor.
     *
     * @param string        $url
     * @param string        $admin
     * @param string        $pw
     * @param DbCredentials $dbCredentials
     */
    private function __construct(string $url, string $admin, string $pw, DbCredentials $dbCredentials)
    {
        $this->url           = $url;
        $this->admin         = $admin;
        $this->pw            = $pw;
        $this->dbCredentials = $dbCredentials;
    }
    
    
    /**
     * Factory method of test configuration.
     *
     * @param string        $url
     * @param string        $admin
     * @param string        $pw
     * @param DbCredentials $dbCredentials
     *
     * @return GxTestConfiguration
     */
    public static function create(string $url, string $admin, string $pw, DbCredentials $dbCredentials) : self
    {
        return new static($url, $admin, $pw, $dbCredentials);
    }
    
    
    /**
     * @return string
     */
    public function url() : string
    {
        return $this->url;
    }
    
    
    /**
     * @return string
     */
    public function admin() : string
    {
        return $this->admin;
    }
    
    
    /**
     * @return string
     */
    public function password() : string
    {
        return $this->pw;
    }
    
    
    /**
     * @return string
     */
    public function dbHost() : string
    {
        return $this->dbCredentials->dbHost();
    }
    
    
    /**
     * @return string
     */
    public function dbUser() : string
    {
        return $this->dbCredentials->dbUser();
    }
    
    
    /**
     * @return string
     */
    public function dbPassword() : string
    {
        return $this->dbCredentials->dbPassword();
    }
    
    
    /**
     * @return string
     */
    public function dbName() : string
    {
        return $this->dbCredentials->dbName();
    }
}