<?php
/* --------------------------------------------------------------
 Service.php 2019-06-14
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Commands\GxTestConfiguration;

use InvalidArgumentException;
use Webmozart\Assert\Assert;

/**
 * Class Service
 * @package Gambio\Dragger\Domain\Commands\GxTestConfiguration
 */
class Service
{
    /**
     * Creates the test configuration file for gx shop.
     *
     * @param GxTestConfiguration $configuration
     * @param string              $destination
     */
    public function createTestsConfig(GxTestConfiguration $configuration, string $destination) : void
    {
        static::assertDestination($destination);
        
        $date = date('Y-m-d');
        $year = date('Y');
        
        $map = [
            '%DATE%'           => $date,
            '%YEAR%'           => $year,
            '%SHOP_URL%'       => $configuration->url(),
            '%ADMIN_USER%'     => $configuration->admin(),
            '%ADMIN_PASSWORD%' => $configuration->password(),
            '%DB_HOST%'        => $configuration->dbHost(),
            '%DB_USER%'        => $configuration->dbUser(),
            '%DB_PASSWORD%'    => $configuration->dbPassword(),
            '%DB_NAME%'        => $configuration->dbName(),
        ];
        
        $stubContent = file_get_contents(__DIR__ . '/stubs/tests.config.inc.php.stub');
        
        foreach ($map as $search => $replace) {
            $stubContent = str_replace($search, $replace, $stubContent);
        }
        
        file_put_contents($destination, $stubContent);
    }
    
    
    /**
     * Asserts destination.
     *
     * @param string $destination
     *
     * @throws InvalidArgumentException If destination is invalid.
     */
    private static function assertDestination(string $destination) : void
    {
        if (is_dir($destination)) {
            throw new InvalidArgumentException("Destination is a directory, but must be a file. ({$destination})");
        }
        
        $pathSegments = explode(DIRECTORY_SEPARATOR, $destination);
        array_pop($pathSegments);
        
        $path = implode(DIRECTORY_SEPARATOR, $pathSegments);
        
        Assert::directory($path);
    }
}