<?php
/* --------------------------------------------------------------
 Destination.php 2019-06-07
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\DbFixture;

use InvalidArgumentException;

/**
 * Class Destination
 * @package Gambio\Dragger\Domain\DbFixture
 */
class Destination
{
    /**
     * @var string
     */
    private $pathname;
    
    
    /**
     * Destination constructor.
     *
     * @param string $pathname
     */
    private function __construct(string $pathname)
    {
        $this->pathname = $this->sanitizeDestination($pathname);
    }
    
    
    /**
     * Factory method for destination.
     *
     * @param string $pathname
     *
     * @return Destination
     */
    public static function fromString(string $pathname) : self
    {
        return new static($pathname);
    }
    
    
    /**
     * Destination pathname.
     *
     * @return string
     */
    public function pathname() : string
    {
        return $this->pathname;
    }
    
    
    /**
     * Sanitizes given path name to match destination criteria and returns realpath.
     *
     * @param string $pathname
     *
     * @return string
     */
    private function sanitizeDestination(string $pathname) : string
    {
        $pathSegments = explode(DIRECTORY_SEPARATOR, $pathname);
        $filename     = array_pop($pathSegments); # remove file name from path segments
        $filepath     = implode(DIRECTORY_SEPARATOR, $pathSegments);
        
        $realpath = realpath($filepath);
        
        if (!$realpath) {
            throw new InvalidArgumentException("Directory of \$pathname does not exist. ({$pathname})");
        }
        if (is_dir($pathname)) {
            throw new InvalidArgumentException("\$pathname must be a file ({$pathname})");
        }
        
        return $realpath . DIRECTORY_SEPARATOR . $filename;
    }
}