<?php
/* --------------------------------------------------------------
 InstallConfiguration.php 2019-06-20
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\GxInstaller;

use Gambio\Dragger\Contracts\Configuration\DbCredentials;
use Gambio\Dragger\Domain\GxInstaller\Steps\CreateAccount\CreateAccountData;
use Gambio\Dragger\Domain\GxInstaller\Steps\WriteConfig\WriteConfigData;

/**
 * Class InstallConfiguration
 * @package Gambio\Dragger\Domain\GxInstaller
 */
class InstallConfiguration
{
    /**
     * @var string
     */
    private $sqlDir;
    
    /**
     * @var DbCredentials
     */
    private $dbCredentials;
    
    /**
     * @var WriteConfigData
     */
    private $configData;
    
    /**
     * @var CreateAccountData
     */
    private $accountData;
    
    
    /**
     * InstallConfiguration constructor.
     *
     * @param string               $sqlDir
     * @param CreateAccountData    $accountData
     * @param DbCredentials|null   $dbCredentials
     * @param WriteConfigData|null $configData
     */
    private function __construct(
        string $sqlDir,
        CreateAccountData $accountData,
        DbCredentials $dbCredentials = null,
        WriteConfigData $configData = null
    ) {
        $this->sqlDir        = $sqlDir;
        $this->dbCredentials = $dbCredentials;
        $this->configData    = $configData;
        $this->accountData   = $accountData;
    }
    
    
    /**
     * Factory method for install config that skips creation of "configure.php" shop files.
     *
     * @param string            $sqlDir
     * @param CreateAccountData $accountData
     *
     * @return InstallConfiguration
     */
    public static function createSkipConfig(
        string $sqlDir,
        CreateAccountData $accountData
    ) : self {
        return new static($sqlDir, $accountData);
    }
    
    
    /**
     * Factory method for install config.
     *
     * @param string            $sqlDir
     * @param CreateAccountData $accountData
     * @param DbCredentials     $dbCredentials
     * @param WriteConfigData   $configData
     *
     * @return InstallConfiguration
     */
    public static function create(
        string $sqlDir,
        CreateAccountData $accountData,
        DbCredentials $dbCredentials,
        WriteConfigData $configData
    ) : self {
        return new static($sqlDir, $accountData, $dbCredentials, $configData);
    }
    
    
    /**
     * @return string
     */
    public function sqlDir() : string
    {
        return $this->sqlDir;
    }
    
    
    /**
     * @return CreateAccountData
     */
    public function accountData() : CreateAccountData
    {
        return $this->accountData;
    }
    
    
    /**
     * @return DbCredentials|null
     */
    public function dbCredentials() : ?DbCredentials
    {
        return $this->dbCredentials;
    }
    
    
    /**
     * @return WriteConfigData|null
     */
    public function configData() : ?WriteConfigData
    {
        return $this->configData;
    }
    
    
    /**
     * @return bool
     */
    public function withConfig() : bool
    {
        return null !== $this->configData;
    }
}