<?php
/* --------------------------------------------------------------
 Service.php 2019-06-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\GxInstaller;

use Gambio\Dragger\Domain\Exception\GxInstaller\InstallationFailedException;
use Gambio\Dragger\Domain\GxInstaller\Steps\CreateAccount;
use Gambio\Dragger\Domain\GxInstaller\Steps\InstallDb;
use Gambio\Dragger\Domain\GxInstaller\Steps\SetupShop;
use Gambio\Dragger\Domain\GxInstaller\Steps\WriteConfig;

/**
 * Class Service
 * @package Gambio\Dragger\Domain\GxInstaller
 */
class Service
{
    /**
     * @var InstallDb
     */
    private $installDb;
    
    /**
     * @var WriteConfig
     */
    private $writeConfig;
    
    /**
     * @var CreateAccount
     */
    private $createAccount;
    
    /**
     * @var SetupShop
     */
    private $setupShop;
    
    
    /**
     * Steps constructor.
     *
     * @param InstallDb     $installDb
     * @param WriteConfig   $writeConfig
     * @param CreateAccount $createAccount
     * @param SetupShop     $setupShop
     */
    public function __construct(
        InstallDb $installDb,
        WriteConfig $writeConfig,
        CreateAccount $createAccount,
        SetupShop $setupShop
    ) {
        $this->installDb     = $installDb;
        $this->writeConfig   = $writeConfig;
        $this->createAccount = $createAccount;
        $this->setupShop     = $setupShop;
    }
    
    
    /**
     * Executes all steps to install a gambio shop.
     *
     * @param InstallConfiguration $configuration
     *
     * @throws InstallationFailedException
     */
    public function installShop(
        InstallConfiguration $configuration
    ) : void {
        $this->installDb->run($configuration->sqlDir());
        
        if ($configuration->withConfig()) {
            $this->writeConfig->run($configuration->configData(), $configuration->dbCredentials());
        }
        
        $this->createAccount->run($configuration->accountData());
        $this->setupShop->run();
    }
}