<?php /** @noinspection SqlResolve */
/* --------------------------------------------------------------
 AddressBookQuery.php 2019-06-19
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\GxInstaller\Steps\CreateAccount;

/**
 * Class AddressBookQuery
 * @package Gambio\Dragger\Domain\GxInstaller\Steps\CreateAccount
 */
class AddressBookQuery
{
    /**
     * Gambio installer query.
     *
     * @return string
     */
    public static function query() : string
    {
        return <<<'QUERY'
INSERT INTO
    `address_book`
(`customers_id`, `entry_company`, `entry_gender`, `entry_firstname`, `entry_lastname`, `entry_street_address`, `entry_postcode`, `entry_city`, `entry_state`, `entry_country_id`, `entry_zone_id`)
VALUES
('1', :company, :gender, :firstName, :lastName, :streetAddress, :postcode, :city, :state, '81', '1355');
QUERY;
    }
    
    
    /**
     * Creates params for prepared statement.
     *
     * @param CreateAccountData $data
     *
     * @return array
     */
    public static function params(CreateAccountData $data) : array
    {
        return [
            'company'       => $data->company(),
            'gender'        => $data->gender(),
            'firstName'     => $data->firstName(),
            'lastName'      => $data->lastName(),
            'streetAddress' => implode(
                ' ', [
                       $data->streetAddress(),
                       $data->houseNumber()
                   ]
            ),
            'postcode'      => $data->postCode(),
            'city'          => $data->city(),
            'state'         => $data->state()
        ];
    }
}

