<?php
/* --------------------------------------------------------------
 WriteConfig.php 2019-06-14
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\GxInstaller\Steps;

use Gambio\Dragger\Contracts\Configuration\DbCredentials;
use Gambio\Dragger\Domain\GxInstaller\Steps\WriteConfig\WriteConfigData;
use function file_get_contents;
use function file_put_contents;
use function str_replace;

/**
 * Class WriteConfig
 * @package Gambio\Dragger\Domain\GxInstaller\Steps
 */
class WriteConfig
{
    /**
     * Writes configuration files for gambio shop.
     *
     * @param WriteConfigData $data
     * @param DbCredentials   $dbCredentials
     */
    public function run(WriteConfigData $data, DbCredentials $dbCredentials) : void
    {
        $httpServer  = $data->ssl() ? 'https://' . $data->server() : 'http://' . $data->server();
        $httpsServer = 'https://' . $data->server();
        $enableSsl   = $data->ssl() ? 'true' : 'false';
        $stubPath    = __DIR__ . '/stubs';
        $stubs       = [
            'frontend' => '/frontend.configure.stub',
            'backend'  => '/backend.configure.stub',
        ];
        
        $search  = [
            '%DOCUMENT_ROOT%',
            '%HTTP_SERVER%',
            '%HTTPS_SERVER%',
            '%ENABLE_SSL%',
            '%DB_HOST%',
            '%DB_USER%',
            '%DB_PASSWORD%',
            '%DB_NAME%',
        ];
        $replace = [
            $data->documentRoot(),
            $httpServer,
            $httpsServer,
            $enableSsl,
            $dbCredentials->dbHost(),
            $dbCredentials->dbUser(),
            $dbCredentials->dbPassword(),
            $dbCredentials->dbName(),
        ];
        
        foreach ($stubs as $key => $stub) {
            $frontend = $key === 'frontend';
            $stubData = file_get_contents($stubPath . $stub);
            $stubData = str_replace($search, $replace, $stubData);
            
            $configureDest = $frontend ? $data->frontendDestination() : $data->backendDestination();
            file_put_contents($configureDest . '/configure.php', $stubData);
        }
    }
}