<?php
/* --------------------------------------------------------------
 WriteConfigData.php 2019-06-20
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\GxInstaller\Steps\WriteConfig;

use Webmozart\Assert\Assert;

/**
 * Class WriteConfigData
 * @package Gambio\Dragger\Domain\GxInstaller\Steps\WriteConfig
 */
class WriteConfigData
{
    
    /**
     * @var string
     */
    private $documentRoot;
    
    /**
     * @var string
     */
    private $server;
    
    /**
     * @var bool
     */
    private $ssl;
    
    /**
     * @var string
     */
    private $frontendDest;
    
    /**
     * @var string
     */
    private $backendDest;
    
    
    /**
     * WriteConfigData constructor.
     *
     * @param string $documentRoot
     * @param string $server
     * @param bool   $ssl
     * @param string $frontendDestination
     * @param string $backendDestination
     */
    public function __construct(
        string $documentRoot,
        string $server,
        bool $ssl,
        string $frontendDestination,
        string $backendDestination
    ) {
        $this->documentRoot = $documentRoot;
        $this->server       = $server;
        $this->ssl          = $ssl;
        $this->frontendDest = $frontendDestination;
        $this->backendDest  = $backendDestination;
    }
    
    
    /**
     * Factory method for WriteConfig data.
     *
     * @param array $data
     *
     * @return WriteConfigData
     */
    public static function fromArray(array $data) : self
    {
        $documentRoot        = static::stringInput($data, 'documentRoot');
        $server              = static::stringInput($data, 'server');
        $ssl                 = static::boolInput($data, 'ssl');
        $frontendDestination = static::stringInput($data, 'frontendDestination');
        $backendDestination  = static::stringInput($data, 'backendDestination');
        
        return new static($documentRoot, $server, $ssl, $frontendDestination, $backendDestination);
    }
    
    
    /**
     * @return string
     */
    public function documentRoot() : string
    {
        return $this->documentRoot;
    }
    
    
    /**
     * @return string
     */
    public function server() : string
    {
        return $this->server;
    }
    
    
    /**
     * @return bool
     */
    public function ssl() : bool
    {
        return $this->ssl;
    }
    
    
    /**
     * @return string
     */
    public function frontendDestination() : string
    {
        return $this->frontendDest;
    }
    
    
    /**
     * @return string
     */
    public function backendDestination() : string
    {
        return $this->backendDest;
    }
    
    
    /**
     * Checks input data for existing key and string type.
     *
     * @param array  $data
     * @param string $key
     *
     * @return string
     */
    private static function stringInput(array $data, string $key) : string
    {
        Assert::keyExists($data, $key);
        $value = $data[$key];
        Assert::string($value);
        
        return $value;
    }
    
    
    /**
     * Checks input for existing key and bool type.
     *
     * @param array  $data
     * @param string $key
     *
     * @return bool
     */
    private static function boolInput(array $data, string $key) : bool
    {
        Assert::keyExists($data, $key);
        $value = $data[$key];
        Assert::boolean($value);
        
        return $value;
    }
}