<?php
/* --------------------------------------------------------------
 HydrahonBuilderFactory.php 2019-08-28
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\QueryBuilder;

use ClanCats\Hydrahon\Builder;
use ClanCats\Hydrahon\Query\Sql;
use ClanCats\Hydrahon\Query\Sql\FetchableInterface;
use PDO;

/**
 * Class HydrahonBuilderFactory
 * @package Gambio\Dragger\Domain\QueryBuilder
 */
class HydrahonBuilderFactory
{
    /**
     * @var Builder|Sql
     */
    private static $builder;
    
    
    /**
     * @param PDO $pdo
     *
     * @return Builder|Sql
     */
    public static function get(PDO $pdo) : Builder
    {
        if (null === static::$builder) {
            static::init($pdo);
        }
        
        return static::$builder;
    }
    
    
    /**
     * Initialization of hydrahon query builder.
     *
     * @param PDO $pdo
     */
    private static function init(PDO $pdo) : void
    {
        static::$builder = new Builder(
            'mysql', static function ($query, $queryString, $queryParameters) use ($pdo) : ?array {
            $statement = $pdo->prepare($queryString);
            $statement->execute($queryParameters);
            
            if ($query instanceof FetchableInterface) {
                return $statement->fetchAll();
            }
            
            return null;
        }
        );
    }
}