<?php
/* --------------------------------------------------------------
 RequestConfiguration.php 2019-08-09
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Configuration;

use Webmozart\Assert\Assert;
use function rtrim;

/**
 * Class RequestConfiguration
 * @package Gambio\Dragger\Domain\Testing\Api\Configuration
 */
class RequestConfiguration
{
    /**
     * @var string
     */
    private $baseUrl;
    
    /**
     * @var string
     */
    private $user;
    
    /**
     * @var string
     */
    private $password;
    
    
    /**
     * RequestConfiguration constructor.
     *
     * @param string $baseUrl
     * @param string $user
     * @param string $password
     */
    private function __construct(string $baseUrl, string $user, string $password)
    {
        Assert::startsWith($baseUrl, 'http', 'Base url must begin with either http:// or https://.');
        
        // ensure base url ends with "/"
        $this->baseUrl  = rtrim($baseUrl, '/') . '/';
        $this->user     = $user;
        $this->password = $password;
    }
    
    
    /**
     * Factory method for RequestConfiguration.
     *
     * @param string $baseUrl
     * @param string $user
     * @param string $password
     *
     * @return RequestConfiguration
     */
    public static function create(string $baseUrl, string $user, string $password) : self
    {
        return new static($baseUrl, $user, $password);
    }
    
    
    /**
     * @return string
     */
    public function baseUrl() : string
    {
        return $this->baseUrl;
    }
    
    
    /**
     * @return string
     */
    public function user() : string
    {
        return $this->user;
    }
    
    
    /**
     * @return string
     */
    public function password() : string
    {
        return $this->password;
    }
}