<?php
/* --------------------------------------------------------------
 DataSetAdded.php 2019-08-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Constraint;

use Gambio\Dragger\Domain\Testing\Api\Failure\Failures;
use Gambio\Dragger\Domain\Testing\Api\Validator\AddedDataSetValidator;
use Gambio\Dragger\Domain\Testing\Api\Verification\Post\PostTestVerification;
use Gambio\Dragger\Infrastructure\Curl\Testing\Api\ApiClient;
use PDO;
use PHPUnit\Framework\Constraint\Constraint;
use PHPUnit\Framework\ExpectationFailedException;
use SebastianBergmann\Comparator\ComparisonFailure;

/**
 * Class DataSetAdded
 * @package Gambio\Dragger\Domain\Testing\Api\Constraint
 */
class DataSetAdded extends Constraint
{
    /**
     * @var AddedDataSetValidator
     */
    private $validator;
    
    
    /**
     * DataSetAdded constructor.
     *
     * @param PDO       $pdo
     * @param ApiClient $apiClient
     */
    public function __construct(PDO $pdo, ApiClient $apiClient)
    {
        parent::__construct();
        $this->validator = new AddedDataSetValidator(Failures::create(), $pdo, $apiClient);
    }
    
    
    /**
     * Evaluates the constraint for parameter $other. Returns true if all expected
     * data sets was added.
     *
     * @param mixed $other
     *
     * @return bool
     */
    protected function matches($other) : bool
    {
        if (!$other instanceof PostTestVerification) {
            return false;
        }
        
        return $this->validator->validate($other);
    }
    
    
    /**
     * Returns a string representation of the object.
     */
    public function toString() : string
    {
        return 'data set was added';
    }
    
    
    /**
     * @param mixed                  $other
     * @param string                 $description
     * @param ComparisonFailure|null $comparisonFailure
     */
    protected function fail($other, $description, ComparisonFailure $comparisonFailure = null) : void
    {
        $failureDescription = $this->validator->failures();
        
        throw new ExpectationFailedException(
            $failureDescription, $comparisonFailure
        );
    }
}