<?php
/* --------------------------------------------------------------
 PutRequest.php 2019-09-02
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

namespace Gambio\Dragger\Domain\Testing\Api\Constraint;

use Gambio\Dragger\Domain\QueryBuilder\HydrahonBuilderFactory;
use Gambio\Dragger\Domain\Testing\Api\Exception\RequestFailedException;
use Gambio\Dragger\Domain\Testing\Api\SimpleEventListener;
use Gambio\Dragger\Domain\Testing\Api\TestCase\AbstractApiTestCase;
use Gambio\Dragger\Domain\Testing\Api\Validator\Put\ChangedStrategy;
use Gambio\Dragger\Domain\Testing\Api\Validator\PutTestValidator;
use Gambio\Dragger\Domain\Testing\Api\Verification\Put\PutTestVerification;
use Gambio\Dragger\Infrastructure\Curl\Testing\Api\ApiClient;
use PDO;
use PHPUnit\Framework\Constraint\Constraint;
use PHPUnit\Framework\ExpectationFailedException;
use SebastianBergmann\Comparator\ComparisonFailure;

/**
 * Class PutRequest
 * @package Gambio\Dragger\Domain\Testing\Api\Constraint
 */
class PutRequest extends Constraint
{
    /**
     * @var PutTestValidator
     */
    private $validator;
    
    /**
     * @var ApiClient
     */
    private $client;
    
    /**
     * @var string|null
     */
    private $requestFailure;
    
    
    /**
     * DeleteRequest constructor.
     *
     * @param PDO       $pdo
     * @param ApiClient $client
     *
     * @Todo: PDO should be replaced with hydran in the whole project.
     */
    public function __construct(PDO $pdo, ApiClient $client)
    {
        parent::__construct();
        
        $qb = HydrahonBuilderFactory::get($pdo);
        
        /** @noinspection PhpParamsInspection */
        $this->validator = PutTestValidator::create(ChangedStrategy::create($qb));
        $this->client    = $client;
    }
    
    
    protected function matches($other) : bool
    {
        if (!$other instanceof PutTestVerification) {
            return false;
        }
        $this->validator->setup($other->expectations());
        try {
            $response = $this->client->requestOrFail(
                $other->requestMethod(),
                $other->requestPath(),
                $other->requestOptions()
            );
        } catch (RequestFailedException $e) {
            $this->requestFailure = $e->getMessage();
            SimpleEventListener::remove(AbstractApiTestCase::EVENT_RECEIVED_RESPONSE);
            
            return false;
        }
        SimpleEventListener::trigger(AbstractApiTestCase::EVENT_RECEIVED_RESPONSE, $response);
        SimpleEventListener::remove(AbstractApiTestCase::EVENT_RECEIVED_RESPONSE);
        
        return $this->validator->validate($other->expectations());
    }
    
    
    /**
     * Returns a string representation of the object.
     */
    public function toString() : string
    {
        return 'put request';
    }
    
    
    /**
     * @param mixed                  $other
     * @param string                 $description
     * @param ComparisonFailure|null $comparisonFailure
     */
    protected function fail($other, $description, ComparisonFailure $comparisonFailure = null) : void
    {
        $failureDescription = $this->validator->failures();
        if ($this->requestFailure) {
            $failureDescription .= PHP_EOL . $this->requestFailure;
        }
        
        throw new ExpectationFailedException(
            $failureDescription, $comparisonFailure
        );
    }
}