<?php
/* --------------------------------------------------------------
 StatusCodeMatches.php 2019-08-12
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Constraint;

use Gambio\Dragger\Domain\Testing\Api\Model\Response as ExpectedResponse;
use PHPUnit\Framework\Constraint\Constraint;
use Psr\Http\Message\ResponseInterface as ActualResponse;

/**
 * Class StatusCodeMatches
 * @package Gambio\Dragger\Domain\Testing\Api\Constraint
 */
class StatusCodeMatches extends Constraint
{
    /**
     * @var ExpectedResponse
     */
    private $expectedResponse;
    
    
    /**
     * StatusCodeMatches constructor.
     *
     * @param ExpectedResponse $expectedResponse
     */
    public function __construct(ExpectedResponse $expectedResponse)
    {
        parent::__construct();
        $this->expectedResponse = $expectedResponse;
    }
    
    
    /**
     * Evaluates the constraint for parameter $other. Returns true if the
     * constraint is met, so the expected status code equals the actual.
     *
     * @param ActualResponse $other
     *
     * @return bool
     */
    protected function matches($other) : bool
    {
        if (!$other instanceof ActualResponse) {
            return false;
        }
        
        return $this->expectedResponse->statusCode() === $other->getStatusCode();
    }
    
    
    /**
     * Returns the description of the failure.
     *
     * @param ActualResponse $other
     *
     * @return string
     */
    protected function failureDescription($other) : string
    {
        if (!$other instanceof ActualResponse) {
            return 'can not evaluate actual response that are not psr7.';
        }
        
        return <<<MSG
status code {$other->getStatusCode()} {$this->toString()} {$this->expectedResponse->statusCode()}
Error reason: {$other->getReasonPhrase()}
MSG;
    }
    
    
    /**
     * Returns a string representation of the object.
     */
    public function toString() : string
    {
        return 'matches expected status code';
    }
}