<?php
/* --------------------------------------------------------------
 Failures.php 2019-08-14
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Failure;

use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\Failure;
use function array_map;
use function count;
use function implode;

/**
 * Class Failures
 * @package Gambio\Dragger\Domain\Testing\Api\Failure
 */
class Failures
{
    /**
     * @var Failure[]
     */
    private $failures = [];
    
    
    /**
     * Failures constructor.
     */
    private function __construct()
    {
    }
    
    
    /**
     * @return Failures
     */
    public static function create() : self
    {
        return new static();
    }
    
    
    /**
     * @param Failure $failure
     */
    public function add(Failure $failure) : void
    {
        $this->failures[] = $failure;
    }
    
    
    /**
     * @return bool
     */
    public function failed() : bool
    {
        return $this->count() !== 0;
    }
    
    
    /**
     * @return int
     */
    public function count() : int
    {
        return count($this->failures);
    }
    
    
    /**
     * Resets internal failure list (by setting to empty array).
     */
    public function reset() : void
    {
        $this->failures = [];
    }
    
    
    /**
     * @return string
     */
    public function toString() : string
    {
        return implode(
            PHP_EOL, array_map(
                       static function (Failure $failure) {
                           return $failure->toString();
                       }, $this->failures
                   )
        );
    }
}