<?php
/* --------------------------------------------------------------
 StringFaker.php 2019-08-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Faker;

use Faker\Generator;
use function strpos;
use function strtolower;

/**
 * Class StringFaker
 * @package Gambio\Dragger\Domain\Testing\Api\Faker
 */
class StringFaker
{
    /**
     * @var Generator
     */
    private $faker;
    
    
    /**
     * StringFaker constructor.
     *
     * @param Generator $faker
     */
    public function __construct(Generator $faker)
    {
        $this->faker = $faker;
    }
    
    
    /**
     * Fakes a string value.
     * If the name is associated with a date, a datetime string will be returned.
     *
     * @param string|null $name
     *
     * @return string
     */
    public function fake(string $name = null) : string
    {
        if (!$name) {
            return $this->faker->word;
        }
        
        $name = strtolower($name);
        
        if ($this->strContains($name, 'date') || $this->strContains($name, 'modified')) {
            return $this->faker->dateTime->format('Y-m-d H:i:s');
        }
        
        return $this->faker->word;
    }
    
    
    /**
     * Checks if $subject contains $needle.
     *
     * @param string $subject
     * @param string $needle
     *
     * @return bool
     */
    private function strContains(string $subject, string $needle) : bool
    {
        return strpos($subject, $needle) !== false;
    }
}