<?php
/* --------------------------------------------------------------
 Properties.php 2019-07-02
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model\Collection;

use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\Property;
use InvalidArgumentException;
use function array_key_exists;

/**
 * Class Properties
 *
 * @package Gambio\Dragger\Domain\Testing\Api\Model\Collection
 */
class Properties
{
    /**
     * @var Property[]
     */
    private $items = [];
    
    
    /**
     * Factory method of Properties.
     *
     * @return Properties
     */
    public static function create() : self
    {
        return new static();
    }
    
    
    /**
     * Adds new collection item.
     *
     * @param Property $property
     */
    public function add(Property $property) : void
    {
        $this->items[$property->name()] = $property;
    }
    
    
    /**
     * @return Property[]
     */
    public function items() : array
    {
        return $this->items;
    }
    
    
    /**
     * Checks if property is available in collection.
     *
     * @param string $identifier
     *
     * @return bool
     */
    public function has(string $identifier) : bool
    {
        return array_key_exists($identifier, $this->items);
    }
    
    
    /**
     * Returns a collection item by the given identifier.
     *
     * @param string $identifier
     *
     * @return Property
     */
    public function get(string $identifier) : Property
    {
        if (!$this->has($identifier)) {
            throw new InvalidArgumentException("Collection item by identifier ({$identifier}) not found.");
        }
        
        return $this->items[$identifier];
    }
}