<?php
/* --------------------------------------------------------------
 Endpoint.php 2019-07-03
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model;

use Gambio\Dragger\Domain\Testing\Api\Model\Collection\Parameters;
use Gambio\Dragger\Domain\Testing\Api\Model\Collection\Responses;
use Gambio\Dragger\Domain\Testing\Api\Model\Parameter\BodyParameter;

/**
 * Class Endpoint
 *
 * @package Gambio\Dragger\Domain\Testing\Api\Model
 */
class Endpoint
{
    /**
     * @var string
     */
    private $path;
    
    /**
     * @var string
     */
    private $method;
    
    /**
     * @var Parameters
     */
    private $parameters;
    
    /**
     * @var Responses
     */
    private $responses;
    
    
    /**
     * Endpoint constructor.
     *
     * @param string     $path
     * @param string     $method
     * @param Parameters $parameters
     * @param Responses  $responses
     */
    private function __construct(string $path, string $method, Parameters $parameters, Responses $responses)
    {
        $this->path       = $path;
        $this->method     = $method;
        $this->parameters = $parameters;
        $this->responses  = $responses;
    }
    
    
    /**
     * Factory method for Endpoint.
     *
     * @param string     $path
     * @param string     $method
     * @param Parameters $parameters
     * @param Responses  $responses
     *
     * @return Endpoint
     */
    public static function create(string $path, string $method, Parameters $parameters, Responses $responses) : self
    {
        return new static($path, $method, $parameters, $responses);
    }
    
    
    /**
     * @return string
     */
    public function path() : string
    {
        return $this->path;
    }
    
    
    /**
     * @return string
     */
    public function method() : string
    {
        return $this->method;
    }
    
    
    /**
     * @return Parameters
     */
    public function parameters() : Parameters
    {
        return $this->parameters;
    }
    
    
    /**
     * @return BodyParameter|null
     */
    public function bodyParameter() : ?BodyParameter
    {
        return $this->parameters->bodyParam();
    }
    
    
    /**
     * @Todo: Endpoint must ensure that exactly one success response is available at time.
     *
     * @return Response
     */
    public function successResponse() : Response
    {
        $response = null;
        
        foreach ($this->responses->items() as $responseItem) {
            if ($responseItem->statusCodeBetween(200, 299)) {
                $response = $responseItem;
            }
        }
        
        return $response;
    }
    
    
    /**
     * @return Responses
     */
    public function responses() : Responses
    {
        return $this->responses;
    }
}
