<?php
/* --------------------------------------------------------------
 SchemaFactory.php 2019-08-06
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model\Factory;

use Gambio\Dragger\Domain\Testing\Api\Model\Collection\Properties;
use Gambio\Dragger\Domain\Testing\Api\Model\Schema\Schema;
use Gambio\Dragger\Domain\Testing\Api\Model\Schema\SchemaList;
use Gambio\Dragger\Domain\Testing\Api\Model\Schema\SchemaListScalar;

/**
 * Class SchemaFactory
 * @package Gambio\Dragger\Domain\Testing\Api\Model\Factory
 *
 * @codeCoverageIgnore (Only simple factory methods, so actually no need for testing).
 */
class SchemaFactory
{
    /**
     * Creates a schema model.
     *
     * @param string     $title
     * @param Properties $properties
     * @param array|null $required
     *
     * @return Schema
     */
    public function createSchema(string $title, Properties $properties, array $required = null) : Schema
    {
        return Schema::create($title, $properties, $required ?? []);
    }
    
    
    /**
     * Creates a schema list model.
     *
     * @param string $title
     * @param Schema $items
     *
     * @return SchemaList
     */
    public function createSchemaList(string $title, Schema $items) : SchemaList
    {
        return SchemaList::create($title, $items);
    }
    
    
    /**
     * Creates a schema list scalar model.
     *
     * @param string $title
     * @param string $type
     *
     * @return SchemaListScalar
     */
    public function createSchemaListScalar(string $title, string $type) : SchemaListScalar
    {
        return SchemaListScalar::create($title, $type);
    }
}