<?php
/* --------------------------------------------------------------
 BodyParameter.php 2019-08-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model\Parameter;

use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\Parameter;
use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\Schema;

/**
 * Class BodyParameter
 * @package Gambio\Dragger\Domain\Testing\Api\Model\Parameter
 */
class BodyParameter implements Parameter
{
    /**
     * @var ParameterCommon
     */
    private $common;
    
    /**
     * @var Schema
     */
    private $schema;
    
    
    /**
     * BodyParameter constructor.
     *
     * @param ParameterCommon $common
     * @param Schema          $schema
     */
    private function __construct(ParameterCommon $common, Schema $schema)
    {
        $this->common = $common;
        $this->schema = $schema;
    }
    
    
    /**
     * Factory method for BodyParameter.
     *
     * @param ParameterCommon $common
     * @param Schema          $schema
     *
     * @return BodyParameter
     */
    public static function create(ParameterCommon $common, Schema $schema) : self
    {
        return new static($common, $schema);
    }
    
    
    /**
     * Returns name of parameter.
     *
     * @return string
     */
    public function name() : string
    {
        return $this->common->name();
    }
    
    
    /**
     * Returns parameter location.
     *
     * @return string
     */
    public function in() : string
    {
        return $this->common->in();
    }
    
    
    /**
     * Flag to determine if parameter is required.
     *
     * @return bool
     */
    public function required() : bool
    {
        return $this->common->required();
    }
    
    
    /**
     * Flag to determine if parameter is list.
     *
     * @return bool
     */
    public function isList() : bool
    {
        return $this->common->isList();
    }
    
    
    /**
     * Returns parameter schema.
     *
     * @return Schema
     */
    public function schema() : Schema
    {
        return $this->schema;
    }
}