<?php
/* --------------------------------------------------------------
 ParameterCommon.php 2019-08-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model\Parameter;

/**
 * Class ParameterCommon
 * @package Gambio\Dragger\Domain\Testing\Api\Model\Parameter
 */
final class ParameterCommon
{
    /**
     * @var string
     */
    private $name;
    
    /**
     * @var string
     */
    private $in;
    
    /**
     * @var bool
     */
    private $required;
    
    /**
     * @var bool
     */
    private $isList;
    
    
    /**
     * PathParameter constructor.
     *
     * @param string $name
     * @param string $in
     * @param bool   $required
     * @param bool   $isList
     */
    private function __construct(string $name, string $in, bool $required, bool $isList)
    {
        $this->name     = $name;
        $this->in       = $in;
        $this->required = $required;
        $this->isList   = $isList;
    }
    
    
    /**
     * Factory method for PathParameter.
     *
     * @param string $name
     * @param string $in
     * @param bool   $required
     * @param bool   $isList
     *
     * @return ParameterCommon
     */
    public static function create(string $name, string $in, bool $required, bool $isList) : self
    {
        return new static($name, $in, $required, $isList);
    }
    
    
    /**
     * Returns name of parameter.
     *
     * @return string
     */
    public function name() : string
    {
        return $this->name;
    }
    
    
    /**
     * Returns parameter location.
     *
     * @return ParameterIn
     */
    public function in() : string
    {
        return $this->in;
    }
    
    
    /**
     * Flag to determine if parameter is required.
     *
     * @return bool
     */
    public function required() : bool
    {
        return $this->required;
    }
    
    
    /**
     * Flag to determine if parameter is list.
     *
     * @return bool
     */
    public function isList() : bool
    {
        return $this->isList;
    }
}