<?php
/* --------------------------------------------------------------
 PathParameter.php 2019-08-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model\Parameter;

use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\Parameter;

/**
 * Class PathParameter
 * @package Gambio\Dragger\Domain\Testing\Api\Model\Parameter
 */
class PathParameter implements Parameter
{
    /**
     * @var ParameterCommon
     */
    private $common;
    
    /**
     * @var string
     */
    private $type;
    
    
    /**
     * PathParameter constructor.
     *
     * @param ParameterCommon $common
     * @param string          $type
     */
    private function __construct(ParameterCommon $common, string $type)
    {
        $this->common = $common;
        $this->type   = $type;
    }
    
    
    /**
     * Factory method for PathParameter.
     *
     * @param ParameterCommon $common
     * @param string          $type
     *
     * @return PathParameter
     */
    public static function create(ParameterCommon $common, string $type) : self
    {
        return new static($common, $type);
    }
    
    
    /**
     * Returns name of parameter.
     *
     * @return string
     */
    public function name() : string
    {
        return $this->common->name();
    }
    
    
    /**
     * Returns parameter location.
     *
     * @return ParameterIn
     */
    public function in() : string
    {
        return $this->common->in();
    }
    
    
    /**
     * Flag to determine if parameter is required.
     *
     * @return bool
     */
    public function required() : bool
    {
        return $this->common->required();
    }
    
    
    /**
     * Flat to determine if parameter is list.
     *
     * @return bool
     */
    public function isList() : bool
    {
        return $this->common->isList();
    }
    
    
    /**
     * Returns parameter type.
     *
     * @return string
     */
    public function type() : string
    {
        return $this->type;
    }
}