<?php
/* --------------------------------------------------------------
 AbstractProperty.php 2019-07-12
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model\Property;

use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\Property;

/**
 * Class AbstractProperty
 *
 * @package Gambio\Dragger\Domain\Testing\Api\Model\Property
 */
abstract class AbstractProperty implements Property
{
    /**
     * @var Property|null
     */
    protected $parent;
    
    
    /**
     * Applies given property as new parent for this property.
     *
     * @param Property $parent
     */
    public function applyParent(Property $parent) : void
    {
        $this->parent = $parent;
    }
    
    
    /**
     * Returns the properties node path.
     * Node path means the property name including parent prop names.
     *
     * @param string $glue
     *
     * @return string
     */
    public function nodePath(string $glue = ' -> ') : string
    {
        $names    = [];
        $property = $this;
        
        while ($property) {
            $names[]  = $property->name();
            $property = $property->parent;
        }
        krsort($names);
        
        return implode($glue, $names);
    }
}