<?php
/* --------------------------------------------------------------
 Response.php 2019-07-03
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model;

use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\SchemaReference;

/**
 * Class Response
 *
 * @package Gambio\Dragger\Domain\Testing\Api\Model
 */
class Response
{
    /**
     * @var int
     */
    private $statusCode;
    
    /**
     * @var SchemaReference
     */
    private $reference;
    
    
    /**
     * Response constructor.
     *
     * @param int             $statusCode
     * @param SchemaReference $schema
     */
    private function __construct(int $statusCode, SchemaReference $schema)
    {
        $this->statusCode = $statusCode;
        $this->reference  = $schema;
    }
    
    
    /**
     * Factory method for Response.
     *
     * @param int             $statusCode
     * @param SchemaReference $schema
     *
     * @return Response
     */
    public static function create(int $statusCode, SchemaReference $schema) : self
    {
        return new static($statusCode, $schema);
    }
    
    
    /**
     * @return int
     */
    public function statusCode() : int
    {
        return $this->statusCode;
    }
    
    
    /**
     * Checks if response status code is between $first and $second value.
     *
     * @param int $first
     * @param int $second
     *
     * @return bool
     */
    public function statusCodeBetween(int $first, int $second) : bool
    {
        return $this->statusCode >= $first && $this->statusCode <= $second;
    }
    
    
    /**
     * @return SchemaReference
     */
    public function reference() : SchemaReference
    {
        return $this->reference;
    }
}