<?php
/* --------------------------------------------------------------
 ReferenceParser.php 2019-08-06
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Resolver;

use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\Reference;
use Symfony\Component\Yaml\Parser;
use function array_values;

/**
 * Class ReferenceParser
 * @package Gambio\Dragger\Domain\Testing\Api\Resolver
 */
class ReferenceParser
{
    /**
     * @var ReferenceResolver
     */
    private $resolver;
    
    /**
     * @var Parser
     */
    private $yamlParser;
    
    
    /**
     * ReferenceParser constructor.
     *
     * @param ReferenceResolver $resolver
     * @param Parser            $yamlParser
     */
    public function __construct(ReferenceResolver $resolver, Parser $yamlParser)
    {
        $this->resolver   = $resolver;
        $this->yamlParser = $yamlParser;
    }
    
    
    /**
     * Parses the reference and returns the content of the resolved file.
     *
     * @param Reference $reference
     *
     * @return array
     */
    public function parse(Reference $reference) : array
    {
        $file = $this->resolver->resolve($reference);
        $data = $this->yamlParser->parseFile($file);
        
        return array_values($data)[0];
    }
}