<?php
/* --------------------------------------------------------------
 ReferenceResolver.php 2019-07-02
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Resolver;

use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\Reference;
use InvalidArgumentException;
use Webmozart\Assert\Assert;
use function str_replace;
use function strlen;
use function substr;

/**
 * Class ReferenceResolver
 *
 * @package Gambio\Dragger\Domain\Testing\Api
 */
class ReferenceResolver
{
    private const DEFINITION_PREFIX = '#/definitions/';
    private const YML_EXTENSION     = '.yml';
    
    /**
     * @var array
     */
    private $definitions;
    
    
    /**
     * ReferenceResolver constructor.
     *
     * @param array $definitions
     */
    public function __construct(array $definitions)
    {
        $this->definitions = $definitions;
    }
    
    
    /**
     * Resolves the reference and returning the path to the file.
     * Throws exception if reference could not get resolved.
     *
     * @param Reference $ref
     *
     * @return string
     */
    public function resolve(Reference $ref) : string
    {
        $reference = $ref->reference();
        Assert::notEmpty($reference);
        
        $filename = str_replace(self::DEFINITION_PREFIX, '', $reference) . self::YML_EXTENSION;
        
        foreach ($this->definitions as $definition) {
            if ($this->endsWith($definition, $filename)) {
                $realPath = realpath($definition);
                
                return $realPath ? : $definition;
            }
        }
        
        throw new InvalidArgumentException("Can not resolve reference (${reference}).");
    }
    
    
    /**
     * Checks if $value ends with $suffix.
     *
     * @param string $value
     * @param string $suffix
     *
     * @return bool
     */
    private function endsWith(string $value, string $suffix) : bool
    {
        return $suffix === substr($value, -strlen($suffix));
    }
}