<?php
/* --------------------------------------------------------------
 DeleteTestCase.php 2019-08-09
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\TestCase;

use Gambio\Dragger\Domain\DbFixture\Fixture;
use Gambio\Dragger\Domain\Testing\Api\AssertApi;
use Gambio\Dragger\Domain\Testing\Api\Verification\Delete\DeleteTestVerification;
use RuntimeException;

/**
 * Class DeleteTestCase
 * @package Gambio\Dragger\Domain\Testing\Api
 */
abstract class DeleteTestCase extends AbstractApiTestCase
{
    /**
     * Asserts that delete request matches test verification.
     *
     * @param DeleteTestVerification $verification
     */
    public function assertDeleteRequest(DeleteTestVerification $verification) : void
    {
        $this->setupFixture();
        $this->setupResponseListener($verification->endpoint());
        
        AssertApi::assertDeleteRequest($verification);
    }
    
    
    /**
     * @return Fixture|null
     */
    protected function initialFixture() : ?Fixture
    {
        $current = get_class($this);
        $method  = __METHOD__;
        $caller  = str_replace(__CLASS__, $current, $method);
        
        $message = <<<MSG
Override {$method}
The method body of {$caller} must override the parents method to setup initial data for the test.
Put request usually depends on data, so the fixture is required!
MSG;
        
        throw new RuntimeException($message);
    }
}