<?php
/* --------------------------------------------------------------
 PostTestCase.php 2019-08-14
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\TestCase;

use Gambio\Dragger\Domain\DbFixture\Fixture;
use Gambio\Dragger\Domain\Testing\Api\AssertApi;
use Gambio\Dragger\Domain\Testing\Api\Verification\Post\PostTestVerification;
use RuntimeException;

/**
 * Class PostTestCase
 * @package Gambio\Dragger\Domain\Testing\Api\TestCase
 */
abstract class PostTestCase extends AbstractApiTestCase
{
    /**
     * Asserts that new data sets was added in database.
     *
     * @param PostTestVerification $verifications
     */
    public function assertDataSetAdded(PostTestVerification $verifications) : void
    {
        $this->setupFixture();
        $this->setupResponseListener($verifications->endpoint());
        
        AssertApi::assertDataSetAdded($verifications);
    }
    
    
    /**
     * @return Fixture|null
     */
    protected function initialFixture() : ?Fixture
    {
        $current = get_class($this);
        $method  = __METHOD__;
        $caller  = str_replace(__CLASS__, $current, $method);
        
        $message = <<<MSG
Override {$method}
The method body of {$caller} must override the parents method to setup initial data for the test.
Put request usually depends on data, so the fixture is required!
MSG;
        
        throw new RuntimeException($message);
    }
}