<?php
/* --------------------------------------------------------------
 RemovedStrategy.php 2019-08-27
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Validator\Delete;

use Gambio\Dragger\Domain\Testing\Api\Contracts\Verification\DeleteValidationStrategy;
use Gambio\Dragger\Domain\Testing\Api\Verification\Delete\Expect;

/**
 * Class RemovedStrategy
 * @package Gambio\Dragger\Domain\Testing\Api\Validator\Delete
 */
class RemovedStrategy extends AbstractDeleteStrategy implements DeleteValidationStrategy
{
    /**
     * Validates the internal data.
     *
     * @param Expect[] $expectations
     *
     * @return bool
     */
    public function validate(Expect ...$expectations) : bool
    {
        $errMsgHead = 'Data set still exists.';
        $this->checkDataSetsExist(false, $errMsgHead, ...$expectations);
        
        return !$this->failures->failed();
    }
    
    
    /**
     * Setup for validation (pre-request).
     * Should be used for example to count data sets before the request happen.
     *
     * @param Expect[] $expectations
     */
    public function setup(Expect ...$expectations) : void
    {
        $this->failures->reset();
        // check if data set with combined it exists
        $errMsgHead = 'Unable to perform check, because initial data set was not found.';
        $this->checkDataSetsExist(true, $errMsgHead, ...$expectations);
    }
}