<?php
/* --------------------------------------------------------------
 AbstractPutStrategy.php 2019-09-04
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Validator\Put;

use ClanCats\Hydrahon\Builder;
use ClanCats\Hydrahon\Query\Sql;
use Gambio\Dragger\Domain\Testing\Api\Failure\Failures;

/**
 * Class AbstractPutStrategy
 * @package Gambio\Dragger\Domain\Testing\Api\Validator\Put
 */
abstract class AbstractPutStrategy
{
    /**
     * @var Builder|Sql
     */
    protected $queryBuilder;
    
    /**
     * @var Failures
     */
    protected $failures;
    
    
    /**
     * AbstractPutStrategy constructor.
     *
     * @param Builder  $queryBuilder
     * @param Failures $failures
     */
    private function __construct(Builder $queryBuilder, Failures $failures)
    {
        $this->queryBuilder = $queryBuilder;
        $this->failures     = $failures;
    }
    
    
    /**
     * Factory method for AbstractPutStrategy.
     *
     * @param Builder $queryBuilder
     *
     * @return AbstractPutStrategy
     */
    public static function create(Builder $queryBuilder) : self
    {
        return new static($queryBuilder, Failures::create());
    }
    
    
    /**
     * @return string
     */
    public function failures() : string
    {
        return $this->failures->toString();
    }
}