<?php
/* --------------------------------------------------------------
 Expect.php 2019-08-30
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Verification\Delete;

/**
 * Class Expect
 * @package Gambio\Dragger\Domain\Testing\Api
 */
class Expect
{
    public const TYPE_REMOVED = 'removed';
    public const TYPE_EXISTS  = 'exists';
    
    /**
     * @var string
     */
    private $table;
    
    /**
     * @var array
     */
    private $columns;
    
    /**
     * @var string
     */
    private $type;
    
    
    /**
     * Expect constructor.
     *
     * @param string $table
     * @param array  $columns
     * @param string $type
     */
    private function __construct(string $table, array $columns, string $type)
    {
        $this->table   = $table;
        $this->columns = $columns;
        $this->type    = $type;
    }
    
    
    /**
     * Factory method for Expect.
     *
     * @param string $table
     * @param array  $columns
     *
     * @return Expect
     */
    public static function removed(string $table, array $columns) : self
    {
        return new static($table, $columns, self::TYPE_REMOVED);
    }
    
    
    /**
     * Factory method for expect.
     *
     * @param string $table
     * @param array  $columns
     *
     * @return Expect
     */
    public static function exists(string $table, array $columns) : self
    {
        return new static($table, $columns, self::TYPE_EXISTS);
    }
    
    
    /**
     * @return string
     */
    public function table() : string
    {
        return $this->table;
    }
    
    
    /**
     * @return array
     */
    public function columns() : array
    {
        return $this->columns;
    }
    
    
    /**
     * Checks if Expect is of $type.
     * Use one of the Expect::TYPE_ constants.
     *
     * @param string $type
     *
     * @return bool
     */
    public function is(string $type) : bool
    {
        return $this->type === $type;
    }
}