<?php
/* --------------------------------------------------------------
 PutAffectedTables.php 2019-08-21
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Verification\Put;

use function array_keys;

/**
 * Class PutAffectedTables
 * @package Gambio\Dragger\Domain\Testing\Api\Verification\Put
 */
class PutAffectedTables
{
    /**
     * @var array
     */
    private $affected = [];
    
    
    /**
     * PutAffectedTables constructor.
     */
    private function __construct()
    {
    }
    
    
    /**
     * @return PutAffectedTables
     */
    public static function create() : self
    {
        return new static();
    }
    
    
    /**
     * @param string $table
     * @param string $identifier
     */
    public function add(string $table, string $identifier) : void
    {
        $this->affected[$table] = $identifier;
    }
    
    
    /**
     * Returns array of affected tables.
     * Format:
     * <pre>
     *  [
     *      $tableName => $tablesIdentifier,
     *  ]
     * </pre>
     * @return array
     */
    public function items() : array
    {
        return $this->affected;
    }
    
    
    /**
     * @return array
     */
    public function tablesOnly() : array
    {
        return array_keys($this->affected);
    }
}