<?php
/* --------------------------------------------------------------
 PutTestVerification.php 2019-08-21
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Verification\Put;

use Faker\Factory;
use Gambio\Dragger\Domain\Testing\Api\Faker\IdentifierChanger;
use Gambio\Dragger\Domain\Testing\Api\Faker\PutRequestFaker;
use Gambio\Dragger\Domain\Testing\Api\Faker\SchemaDataFaker;
use Gambio\Dragger\Domain\Testing\Api\Model\Endpoint;
use Gambio\Dragger\Domain\Testing\Api\Traits\EndpointUrlResolver;

/**
 * Class PutTestVerification
 * @package Gambio\Dragger\Domain\Testing\Api\Verification\Put
 */
class PutTestVerificationBak
{
    use EndpointUrlResolver;
    
    /**
     * @var Endpoint
     */
    private $endpoint;
    
    /**
     * @var PutAffectedIds
     */
    private $affectedIds;
    
    /**
     * @var PutAffectedTables
     */
    private $affectedTables;
    
    /**
     * @var array
     */
    private $placeholders;
    
    /**
     * @var PutRequestFaker
     */
    private $faker;
    
    
    /**
     * PutTestVerification constructor.
     *
     * @param Endpoint          $endpoint
     * @param PutAffectedIds    $affectedIds
     * @param PutAffectedTables $affectedTables
     * @param array             $placeholders
     * @param PutRequestFaker   $faker
     */
    public function __construct(
        Endpoint $endpoint,
        PutAffectedIds $affectedIds,
        PutAffectedTables $affectedTables,
        array $placeholders,
        PutRequestFaker $faker
    ) {
        $this->endpoint       = $endpoint;
        $this->affectedIds    = $affectedIds;
        $this->affectedTables = $affectedTables;
        $this->placeholders   = $placeholders;
        $this->faker          = $faker;
    }
    
    
    /**
     * Factory method for PutTestVerification.
     *
     * @param Endpoint          $endpoint
     * @param PutAffectedIds    $affectedIds
     * @param PutAffectedTables $affectedTables
     * @param array             $placeholders
     *
     * @return PutTestVerificationBak
     */
    public static function create(
        Endpoint $endpoint,
        PutAffectedIds $affectedIds,
        PutAffectedTables $affectedTables,
        array $placeholders = []
    ) : self {
        $faker = new PutRequestFaker(new SchemaDataFaker(Factory::create('de_DE')), new IdentifierChanger());
        
        return new static($endpoint, $affectedIds, $affectedTables, $placeholders, $faker);
    }
    
    
    /**
     * @return Endpoint
     */
    public function endpoint() : Endpoint
    {
        return $this->endpoint;
    }
    
    
    /**
     * @return PutAffectedIds
     */
    public function affectedIds() : PutAffectedIds
    {
        return $this->affectedIds;
    }
    
    
    /**
     * @return PutAffectedTables
     */
    public function affectedTables() : PutAffectedTables
    {
        return $this->affectedTables;
    }
    
    
    /**
     * @return string
     */
    public function requestMethod() : string
    {
        return $this->endpoint->method();
    }
    
    
    /**
     * @return string
     */
    public function requestPath() : string
    {
        // usually, put request do not have url params
        // if so, the path param validator will show what went wrong
        return $this->resolveEndpointUrl($this->endpoint, $this->placeholders);
    }
    
    
    /**
     * @return array
     */
    public function requestOptions() : array
    {
        $body = $this->endpoint->bodyParameter();
        if ($body) {
            return [
                'json' => $this->faker->fake(
                    $body->schema(),
                    $this->affectedIds->bodyIdentifier(),
                    ...$this->affectedIds->ids()
                )
            ];
        }
        
        return [];
    }
}