<?php
/* --------------------------------------------------------------
 RecursiveDirectoryScanner.php 2019-07-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Infrastructure\Fs;

use RecursiveDirectoryIterator as Dir;
use RecursiveIteratorIterator as Iterator;
use SplFileInfo;
use Webmozart\Assert\Assert;

/**
 * Class RecursiveDirectoryScanner
 *
 * @package Gambio\Dragger\Infrastructure\Fs
 */
class RecursiveDirectoryScanner
{
    /**
     * Scans all files in the given path and returns their absolute paths as array.
     *
     * @param string $path
     *
     * @return array
     */
    public static function scanFiles(string $path) : array
    {
        Assert::fileExists($path);
        $iterator = new Iterator(new Dir($path, Dir::SKIP_DOTS), Iterator::CHILD_FIRST);
        $files    = [];
        
        foreach ($iterator as $file) {
            /** @var SplFileInfo $file */
            if ($file->isFile()) {
                $files[] = realpath($file->getPathname());
            }
        }
        
        return $files;
    }
}