<?php
/* --------------------------------------------------------------
 SqlFileReader.php 2019-06-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Infrastructure\Persistence\Commands\Sql;

use DirectoryIterator as Directory;
use Gambio\Dragger\Domain\Commands\Sql\Path;
use Gambio\Dragger\Domain\Commands\Sql\SqlFileCollection;
use Gambio\Dragger\Domain\Commands\Sql\SqlFileFactory;
use IteratorIterator as Iterator;
use SplFileInfo;

/**
 * Class SqlFileReader
 * @package Gambio\Dragger\Infrastructure\Persistence\Commands\Sql
 */
class SqlFileReader
{
    /**
     * @var SqlFileFactory
     */
    private $factory;
    
    
    /**
     * SqlFileReader constructor.
     *
     * @param SqlFileFactory $factory
     */
    public function __construct(SqlFileFactory $factory)
    {
        $this->factory = $factory;
    }
    
    
    /**
     * Scans the given path for sql files and returns a collection of them.
     *
     * @param Path $path
     *
     * @return SqlFileCollection
     */
    public function scan(Path $path) : SqlFileCollection
    {
        $collection = $this->factory->createSqlFileCollection();
        $iterator   = new Iterator(new Directory($path->toString()));
        
        $files = [];
        foreach ($iterator as $file) {
            /** @var SplFileInfo $file */
            if ($file->getExtension() === 'sql') {
                $files[] = $file->getPathname();
            }
        }
        
        sort($files);
        foreach ($files as $filePath) {
            $sqlFile = $this->factory->createSqlFile($filePath);
            $collection->add($sqlFile);
        }
        
        return $collection;
    }
}