<?php
/* --------------------------------------------------------------
 PdoMySqlRepository.php 2019-06-07
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Infrastructure\Persistence\DbFixture;

use Gambio\Dragger\Domain\DbFixture\DbFixtureRepository;
use Gambio\Dragger\Domain\DbFixture\Destination;
use Gambio\Dragger\Domain\DbFixture\Fixture;
use Gambio\Dragger\Domain\DbFixture\NewFixture;
use Gambio\Dragger\Domain\DbFixture\Tables;

/**
 * Class PdoMySqlRepository
 * @package Gambio\Dragger\Infrastructure\Persistence\DbFixture
 */
class PdoMySqlRepository implements DbFixtureRepository
{
    /**
     * @var PdoMySqlReader
     */
    private $reader;
    /**
     * @var PdoMySqlWriter
     */
    private $writer;
    
    /**
     * @var TableDataProcessor
     */
    private $processor;
    
    
    /**
     * PdoMySqlRepository constructor.
     *
     * @param PdoMySqlReader     $reader
     * @param PdoMySqlWriter     $writer
     * @param TableDataProcessor $processor
     */
    public function __construct(PdoMySqlReader $reader, PdoMySqlWriter $writer, TableDataProcessor $processor)
    {
        $this->reader    = $reader;
        $this->writer    = $writer;
        $this->processor = $processor;
    }
    
    
    /**
     * Creates a database fixture of the given tables.
     *
     * @param Tables $tables Tables of created database fixture.
     *
     * @return NewFixture
     */
    public function create(Tables $tables) : NewFixture
    {
        $data    = $this->reader->fetchData($tables->list());
        $content = $this->processor->createContent($data);
        
        return NewFixture::fromString($content);
    }
    
    
    /**
     * Saves the given fixture to destination.
     *
     * @param NewFixture  $fixture
     * @param Destination $destination
     *
     * @codeCoverageIgnore Currently to simple to put any effort in tests.
     */
    public function save(NewFixture $fixture, Destination $destination) : void
    {
        file_put_contents($destination->pathname(), $fixture->content());
    }
    
    
    /**
     * Imports the given fixture file.
     *
     * @param Fixture $fixture
     *
     * @return mixed
     */
    public function import(Fixture $fixture) : void
    {
        $this->writer->import($fixture->data());
    }
}