<?php
/* --------------------------------------------------------------
 EndpointMapper.php 2019-07-03
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Infrastructure\Persistence\Testing\Api;

use Gambio\Dragger\Domain\Testing\Api\Model\Endpoint;
use Gambio\Dragger\Domain\Testing\Api\Model\Factory\ParameterFactory;
use Gambio\Dragger\Domain\Testing\Api\Model\Factory\SimpleFactory;
use UnexpectedValueException;

/**
 * Class EndpointMapper
 *
 * @package Gambio\Dragger\Infrastructure\Persistence\Testing\Api
 */
class EndpointMapper
{
    /**
     * @var SimpleFactory
     */
    private $simpleFactory;
    
    /**
     * @var ParameterFactory
     */
    private $parameterFactory;
    
    
    /**
     * EndpointMapper constructor.
     *
     * @param SimpleFactory    $simpleFactory
     * @param ParameterFactory $parameterFactory
     */
    public function __construct(SimpleFactory $simpleFactory, ParameterFactory $parameterFactory)
    {
        $this->simpleFactory    = $simpleFactory;
        $this->parameterFactory = $parameterFactory;
    }
    
    
    public function map(array $data) : Endpoint
    {
        $parameters = $this->parameterFactory->createParameters();
        $responses  = $this->simpleFactory->createResponses();
        
        foreach ($data as $path => $methodData) {
            /** @noinspection LoopWhichDoesNotLoopInspection */
            foreach ($methodData as $method => $endpointData) {
                foreach ($endpointData['responses'] as $statusCode => $response) {
                    $reference = $this->simpleFactory->createSchemaReference($response['schema']);
                    $response  = $this->simpleFactory->createResponse($statusCode, $reference);
                    
                    $responses->add($response);
                }
                
                foreach ($endpointData['parameters'] as $paramData) {
                    // Todo: Skip reference params for now (usually query params that will be implemented later)
                    if (!array_key_exists('$ref', $paramData)) {
                        $parameter = $this->parameterFactory->create($paramData);
                        $parameters->add($parameter);
                    }
                }
                
                return $this->simpleFactory->createEndpoint($path, $method, $parameters, $responses);
            }
        }
        
        throw new UnexpectedValueException('Invalid data provided for endpoint mapping.');
    }
}