<?php
/* --------------------------------------------------------------
 DestinationTest.php 2019-06-07
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\DbFixture;

use InvalidArgumentException;
use PHPUnit\Framework\TestCase;

class DestinationTest extends TestCase
{
    public function testHasAccessiblePathname() : void
    {
        $pathname    = __DIR__ . '/foo.php';
        $destination = Destination::fromString($pathname);
        
        $this->assertEquals($pathname, $destination->pathname());
    }
    
    
    /**
     * @param string $invalidPath
     *
     * @dataProvider invalidPathDataProvider
     */
    public function testRejectsInvalidPaths(string $invalidPath) : void
    {
        $this->expectException(InvalidArgumentException::class);
        Destination::fromString($invalidPath);
    }
    
    
    public function invalidPathDataProvider() : array
    {
        return [
            'is_dir_only'    => [__DIR__],
            'dir_not_exists' => [__DIR__ . '/invalid/foo.php']
        ];
    }
}