<?php
/* --------------------------------------------------------------
 FixtureTest.php 2019-06-07
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\DbFixture;

use InvalidArgumentException;
use PHPUnit\Framework\TestCase;

class FixtureTest extends TestCase
{
    public function testExposesExistingFixtureFile() : void
    {
        $data    = include __DIR__ . '/fixtures/SampleFixture.php';
        $fixture = Fixture::fromFile(__DIR__ . '/fixtures/SampleFixture.php');
        
        $this->assertEquals($data, $fixture->data());
    }
    
    
    /**
     * @param string $invalidFilepath
     *
     * @dataProvider invalidFilepathDataProvider
     */
    public function testRejectsInvalidFixtureFiles(string $invalidFilepath) : void
    {
        $this->expectException(InvalidArgumentException::class);
        Fixture::fromFile($invalidFilepath);
    }
    
    
    public function invalidFilepathDataProvider() : array
    {
        return [
            'is_dir'          => [__DIR__],
            'not_exists'      => [__DIR__ . '/invalid'],
            'invalid_fixture' => [__DIR__ . '/fixtures/InvalidFixture.php']
        ];
    }
}