<?php
/* --------------------------------------------------------------
 WriteConfigTest.php 2019-06-14
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\GxInstaller\Steps;

use Gambio\Dragger\Core\DbCredentials;
use Gambio\Dragger\Domain\GxInstaller\Steps\WriteConfig\WriteConfigData;
use PHPUnit\Framework\TestCase;

class WriteConfigTest extends TestCase
{
    public function testCreatesShopConfigureFiles() : void
    {
        $destination      = __DIR__ . '/fixtures/frontend';
        $adminDestination = __DIR__ . '/fixtures/backend';
        
        $credentials = DbCredentials::create('db_host', 'db_user', 'db_password', 'db_name');
        $configData  = [
            'documentRoot'        => '/var/www/html/',
            'server'              => 'localhost',
            'ssl'                 => true,
            'frontendDestination' => $destination,
            'backendDestination'  => $adminDestination,
        ];
        
        $data = WriteConfigData::fromArray($configData);
        
        $writeConfig = new WriteConfig();
        $writeConfig->run($data, $credentials);
        
        $expected = [
            'frontend' => $this->normalizeLinebreaks(file_get_contents(__DIR__ . '/fixtures/example-configure.php')),
            'backend'  => $this->normalizeLinebreaks(
                file_get_contents(__DIR__ . '/fixtures/example-admin-configure.php')
            ),
        ];
        $actual   = [
            'frontend' => $this->normalizeLinebreaks(file_get_contents(__DIR__ . '/fixtures/frontend/configure.php')),
            'backend'  => $this->normalizeLinebreaks(file_get_contents(__DIR__ . '/fixtures/backend/configure.php')),
        ];
        
        $this->assertEquals($expected, $actual);
    }
    
    
    private function normalizeLinebreaks(string $subject) : string
    {
        $search  = "\r\n";
        $replace = "\n";
        
        return str_replace($search, $replace, $subject);
    }
    
    
    protected function tearDown()
    {
        $frontend = __DIR__ . '/fixtures/frontend/configure.php';
        $backend  = __DIR__ . '/fixtures/backend/configure.php';
        
        if (file_exists($frontend)) {
            @unlink($frontend);
        }
        if (file_exists($backend)) {
            @unlink($backend);
        }
    }
}