<?php
/* --------------------------------------------------------------
 FailuresTest.php 2019-08-14
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Failure;

use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\Failure;
use PHPUnit\Framework\TestCase;

class FailuresTest extends TestCase
{
    /**
     * @var Failures
     */
    private $failures;
    
    
    protected function setUp()
    {
        $this->failures = Failures::create();
    }
    
    
    public function testReturnsTrueForIsFailedIfAtLeastOneFailureItemWasProvidedBefore() : void
    {
        $errors = [];
        
        if ($this->failures->failed()) {
            $errors[] = 'Failed asserting that empty Failures should not be failed.';
        }
        
        $this->failures->add($this->createFailure());
        
        if (!$this->failures->failed()) {
            $errors[] = 'Failed asserting that existing failure should be failed.';
        }
        
        $this->assertCount(0, $errors, implode(PHP_EOL, $errors));
    }
    
    
    public function testCanBeReset() : void
    {
        $failure = $this->createMock(Failure::class);
        $this->failures->add($failure);
        $this->failures->reset();
        
        $this->assertFalse($this->failures->failed(), 'Could not reset failures');
    }
    
    
    private function createFailure() : Failure
    {
        /** @noinspection PhpIncompatibleReturnTypeInspection */
        return $this->createMock(Failure::class);
    }
}
