<?php
/* --------------------------------------------------------------
 StringFakerTest.php 2019-08-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Faker;

use Faker\Factory;
use PHPUnit\Framework\TestCase;

class StringFakerTest extends TestCase
{
    /**
     * @var StringFaker
     */
    private $faker;
    
    
    protected function setUp()
    {
        $this->faker = new StringFaker(Factory::create('de_DE'));
    }
    
    
    public function testEmptyNameReturnsSingleWord() : void
    {
        $actual       = $this->faker->fake();
        $error        = null;
        $errorMessage = 'Failed asserting that ::fake without args returns single word.';
        
        $verify = explode(' ', $actual);
        if (count($verify) !== 1) {
            $this->fail($errorMessage);
        }
        
        if ($verify[0] === '') {
            $this->fail($errorMessage);
        }
        
        $this->assertTrue(true);
    }
    
    
    /**
     * @param string $name
     *
     * @dataProvider dateNameDataProvider
     */
    public function testNameThatContainsWordDateReturnsStringInDateTimeFormat(string $name) : void
    {
        $actual        = $this->faker->fake($name);
        $dateTimeRegex = '/^\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}$/';
        
        $this->assertRegExp($dateTimeRegex, $actual, 'Invalid date time format.');
    }
    
    
    public function dateNameDataProvider() : array
    {
        return [
            ['lastModified'],
            ['dateAdded'],
        ];
    }
}
