<?php
/* --------------------------------------------------------------
 PropertiesTest.php 2019-07-02
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model\Collection;

use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\Property;
use InvalidArgumentException;
use PHPUnit\Framework\TestCase;

/**
 * Class PropertiesTest
 *
 * @package Gambio\Dragger\Domain\Testing\Api\Model\Collection
 */
class PropertiesTest extends TestCase
{
    /**
     * @var Properties
     */
    private $collection;
    
    
    protected function setUp()
    {
        $this->collection = Properties::create();
    }
    
    
    public function testAddsNewItemsOnDemand() : void
    {
        $item = $this->createConfiguredMock(
            Property::class, [
                               'name' => 'foo'
                           ]
        );
        $this->collection->add($item);
        $this->assertSame(['foo' => $item], $this->collection->items());
    }
    
    
    public function testCanCheckIfItemExists() : void
    {
        $item = $this->createConfiguredMock(
            Property::class, [
                               'name' => 'foo'
                           ]
        );
        $this->collection->add($item);
        $errors = [];
        
        if (!$this->collection->has('foo')) {
            $errors[] = 'Can not find existing item "foo"';
        }
        if ($this->collection->has('bar')) {
            $errors[] = 'Found non existent item "bar"';
        }
        
        $this->assertCount(0, $errors, implode(PHP_EOL, $errors));
    }
    
    
    public function testReturnsItemByIdentifier() : void
    {
        $item = $this->createConfiguredMock(
            Property::class, [
                               'name' => 'foo'
                           ]
        );
        $this->collection->add($item);
        $this->assertSame($item, $this->collection->get('foo'));
    }
    
    
    public function testThrowsExceptionIfNonExistingItemShouldGet() : void
    {
        $this->expectException(InvalidArgumentException::class);
        $this->collection->get('foo');
    }
}