<?php
/* --------------------------------------------------------------
 EndpointTest.php 2019-07-03
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model;

use Faker\Factory;
use Gambio\Dragger\Domain\Testing\Api\Model\Collection\Parameters;
use Gambio\Dragger\Domain\Testing\Api\Model\Collection\Responses;
use Gambio\Dragger\Domain\Testing\Api\Model\Parameter\BodyParameter;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

class EndpointTest extends TestCase
{
    /**
     * @var Endpoint
     */
    private $endpoint;
    
    /**
     * @var string
     */
    private $path;
    
    /**
     * @var string
     */
    private $method;
    
    /**
     * @var MockObject|Parameters
     */
    private $parameters;
    
    /**
     * @var MockObject|Responses
     */
    private $responses;
    
    /**
     * @var MockObject|BodyParameter
     */
    private $bodyParam;
    
    
    protected function setUp()
    {
        $faker = Factory::create('de_DE');
        
        $this->path       = '/' . $faker->word;
        $this->method     = $faker->randomElement(['get', 'post', 'put', 'patch', 'delete']);
        $this->bodyParam  = $this->createMock(BodyParameter::class);
        $this->parameters = $this->createConfiguredMock(Parameters::class, ['bodyParam' => $this->bodyParam]);
        $this->responses  = $this->createMock(Responses::class);
        
        $this->endpoint = Endpoint::create($this->path, $this->method, $this->parameters, $this->responses);
    }
    
    
    public function testHasPath() : void
    {
        $this->assertEquals($this->path, $this->endpoint->path());
    }
    
    
    public function testHasMethod() : void
    {
        $this->assertEquals($this->method, $this->endpoint->method());
    }
    
    
    public function testHasParameters() : void
    {
        $this->assertSame($this->parameters, $this->endpoint->parameters());
    }
    
    
    public function testHasResponses() : void
    {
        $this->assertSame($this->responses, $this->endpoint->responses());
    }
    
    
    public function testHasBodyParam() : void
    {
        $this->assertSame($this->bodyParam, $this->endpoint->bodyParameter());
    }
}
