<?php
/* --------------------------------------------------------------
 BodyParameterTest.php 2019-08-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model\Parameter;

use Faker\Factory;
use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\Schema;
use PHPUnit\Framework\TestCase;

class BodyParameterTest extends TestCase
{
    /**
     * @var BodyParameter
     */
    private $bodyParameter;
    
    /**
     * @var ParameterCommon
     */
    private $common;
    
    /**
     * @var string
     */
    private $paramName;
    
    /**
     * @var string
     */
    private $in;
    
    /**
     * @var bool
     */
    private $required;
    
    /**
     * @var bool
     */
    private $isList;
    
    /**
     * @var Schema
     */
    private $schema;
    
    
    protected function setUp()
    {
        $faker = Factory::create('de_DE');
        
        $this->paramName = $faker->word;
        $this->in        = $faker->boolean ? 'path' : 'body';
        $this->required  = $faker->boolean;
        $this->schema    = $this->createMock(Schema::class);
        $this->isList    = $faker->boolean;
        
        $this->common = ParameterCommon::create(
            $this->paramName, $this->in, $this->required, $this->isList
        );
        
        $this->bodyParameter = BodyParameter::create(
            $this->common, $this->schema
        );
    }
    
    
    public function testHasName() : void
    {
        $this->assertEquals($this->paramName, $this->bodyParameter->name());
    }
    
    
    public function testHasIn() : void
    {
        $this->assertEquals($this->in, $this->bodyParameter->in());
    }
    
    
    public function testCanBeRequired() : void
    {
        $this->assertEquals($this->required, $this->bodyParameter->required());
    }
    
    
    public function testCanBeList() : void
    {
        $this->assertEquals($this->isList, $this->bodyParameter->isList());
    }
    
    
    public function testHasSchema() : void
    {
        $this->assertEquals($this->schema, $this->bodyParameter->schema());
    }
}
