<?php
/* --------------------------------------------------------------
 PathParameterTest.php 2019-08-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model\Parameter;

use Faker\Factory;
use PHPUnit\Framework\TestCase;

class PathParameterTest extends TestCase
{
    /**
     * @var PathParameter
     */
    private $pathParameter;
    
    /**
     * @var ParameterCommon
     */
    private $common;
    
    /**
     * @var string
     */
    private $paramName;
    
    /**
     * @var string
     */
    private $in;
    
    /**
     * @var bool
     */
    private $required;
    
    /**
     * @var string
     */
    private $type;
    
    /**
     * @var bool
     */
    private $isList;
    
    
    protected function setUp()
    {
        $faker = Factory::create('de_DE');
        
        $this->paramName = $faker->word;
        $this->in        = $faker->boolean ? 'path' : 'body';
        $this->required  = $faker->boolean;
        $this->type      = $faker->boolean ? 'string' : 'integer';
        $this->isList    = $faker->boolean;
        
        $this->common = ParameterCommon::create(
            $this->paramName, $this->in, $this->required, $this->isList
        );
        
        $this->pathParameter = PathParameter::create(
            $this->common, $this->type
        );
    }
    
    
    public function testHasName() : void
    {
        $this->assertEquals($this->paramName, $this->pathParameter->name());
    }
    
    
    public function testHasIn() : void
    {
        $this->assertEquals($this->in, $this->pathParameter->in());
    }
    
    
    public function testCanBeRequired() : void
    {
        $this->assertEquals($this->required, $this->pathParameter->required());
    }
    
    
    public function testHasType() : void
    {
        $this->assertEquals($this->type, $this->pathParameter->type());
    }
    
    
    public function testCanBeList() : void
    {
        $this->assertEquals($this->isList, $this->pathParameter->isList());
    }
}
