<?php
/* --------------------------------------------------------------
 ObjectPropertyTest.php 2019-07-05
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model\Property;

use Faker\Factory;
use Gambio\Dragger\Domain\Testing\Api\Model\Collection\Properties;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

class ObjectPropertyTest extends TestCase
{
    /**
     * @var ObjectProperty
     */
    private $property;
    
    /**
     * @var string
     */
    private $propName;
    
    /**
     * @var MockObject|Properties
     */
    private $properties;
    
    /**
     * @var array
     */
    private $required;
    
    
    protected function setUp()
    {
        $faker = Factory::create('de_DE');
        
        $this->propName   = $faker->word;
        $this->properties = $this->createMock(Properties::class);
        $this->required   = $faker->randomElements(['foo', 'bar', 'baz']);
        
        $this->property = ObjectProperty::create($this->propName, $this->properties, $this->required);
    }
    
    
    public function testHasName() : void
    {
        $this->assertEquals($this->propName, $this->property->name());
    }
    
    
    public function testHasProperties() : void
    {
        $this->assertSame($this->properties, $this->property->properties());
    }
    
    
    public function testHasOptionalRequired() : void
    {
        $this->assertSame($this->required, $this->property->required());
    }
}
