<?php
/* --------------------------------------------------------------
 ScalarPropertyTest.php 2019-07-02
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Model\Property;

use Faker\Factory;
use Faker\Generator;
use PHPUnit\Framework\TestCase;

class ScalarPropertyTest extends TestCase
{
    /**
     * @var ScalarProperty
     */
    private $property;
    
    /**
     * @var Generator
     */
    private $faker;
    
    /**
     * @var string
     */
    private $propName;
    
    /**
     * @var string
     */
    private $type;
    
    
    protected function setUp()
    {
        $this->faker = Factory::create('de_DE');
        
        $this->propName = $this->faker->word;
        $this->type     = $this->faker->randomElement(['integer', 'string', 'boolean']);
        
        $this->property = ScalarProperty::create($this->propName, $this->type);
    }
    
    
    public function testHasName() : void
    {
        $this->assertEquals($this->propName, $this->property->name());
    }
    
    
    public function testHasType() : void
    {
        $this->assertEquals($this->type, $this->property->type());
    }
    
    
    public function testCanBeNullable() : void
    {
        $this->propName = $this->faker->word;
        $this->type     = $this->faker->randomElement(['integer', 'string', 'boolean']);
        
        $this->property = ScalarProperty::create($this->propName, $this->type, true);
        
        $this->assertTrue($this->property->isNullable());
    }
}