<?php
/* --------------------------------------------------------------
 ReferenceResolverTest.php 2019-07-02
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Domain\Testing\Api\Resolver;

use Gambio\Dragger\Domain\Testing\Api\Model\Contracts\Reference;
use InvalidArgumentException;
use PHPUnit\Framework\TestCase;

class ReferenceResolverTest extends TestCase
{
    private const DEFINITIONS_PARAM = [
        './categories/GXCategory.yml',
        './categories/GXCategoryArray.yml',
        './products/GXProduct.yml',
        './products/GXProductAddonValues.yml',
    ];
    
    /**
     * @var ReferenceResolver
     */
    private $resolver;
    
    
    protected function setUp()
    {
        $this->resolver = new ReferenceResolver(self::DEFINITIONS_PARAM);
    }
    
    
    public function testResolvesDefinitionsToFile() : void
    {
        $reference = '#/definitions/GXProduct';
        $reference = $this->createConfiguredMock(
            Reference::class, [
                                'reference' => $reference
                            ]
        );
        $expected  = './products/GXProduct.yml';
        $actual    = $this->resolver->resolve($reference);
        
        $this->assertEquals($expected, $actual);
    }
    
    
    public function testThrowsExceptionIfDefinitionWasNotFound() : void
    {
        $this->expectException(InvalidArgumentException::class);
        $reference = $this->createConfiguredMock(Reference::class, ['reference' => 'invalid']);
        $this->resolver->resolve($reference);
    }
}