<?php
/* --------------------------------------------------------------
 PdoSqlRepositoryTest.php 2019-06-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Infrastructure\Persistence\Commands\Sql;

use Gambio\Dragger\Domain\Commands\Sql\Path;
use Gambio\Dragger\Domain\Commands\Sql\SqlFile;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

class PdoSqlRepositoryTest extends TestCase
{
    /**
     * @var PdoSqlRepository
     */
    private $repository;
    
    /**
     * @var MockObject|SqlFileReader
     */
    private $reader;
    
    /**
     * @var MockObject|SqlFilePdoWriter
     */
    private $writer;
    
    
    protected function setUp()
    {
        $this->reader = $this->createMock(SqlFileReader::class);
        $this->writer = $this->createMock(SqlFilePdoWriter::class);
        
        $this->repository = new PdoSqlRepository($this->reader, $this->writer);
    }
    
    
    public function testUsesReaderToScanSqlFileCollection() : void
    {
        $path = $this->createMock(
            Path::class, [
                           'toString' => __DIR__
                       ]
        );
        
        $this->reader->expects($this->once())->method('scan')->with($this->equalTo($path));
        
        $this->repository->scan($path);
    }
    
    
    public function testUsesWriterToImportSqlFile() : void
    {
        $sqlFile = $this->createMock(SqlFile::class);
        
        $this->writer->expects($this->once())->method('run')->with($this->equalTo($sqlFile));
        
        $this->repository->import($sqlFile);
    }
}