<?php
/* --------------------------------------------------------------
 PdoMySqlRepositoryTest.php 2019-06-07
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2019 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace Gambio\Dragger\Infrastructure\Persistence\DbFixture;

use Gambio\Dragger\Domain\DbFixture\Fixture;
use Gambio\Dragger\Domain\DbFixture\Tables;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

class PdoMySqlRepositoryTest extends TestCase
{
    /**
     * @var PdoMySqlRepository
     */
    private $repository;
    
    /**
     * @var MockObject|PdoMySqlReader
     */
    private $reader;
    
    /**
     * @var MockObject|PdoMySqlWriter
     */
    private $writer;
    
    /**
     * @var MockObject|TableDataProcessor
     */
    private $processor;
    
    
    protected function setUp()
    {
        $this->reader    = $this->createMock(PdoMySqlReader::class);
        $this->writer    = $this->createMock(PdoMySqlWriter::class);
        $this->processor = $this->createMock(TableDataProcessor::class);
        
        $this->repository = new PdoMySqlRepository($this->reader, $this->writer, $this->processor);
    }
    
    
    public function testMessagesReaderToFetchTableData() : void
    {
        $tableList = ['products', 'categories'];
        
        $tables = $this->createConfiguredMock(
            Tables::class, [
                             'list' => $tableList
                         ]
        );
        $this->reader->expects($this->once())->method('fetchData')->with($this->equalTo($tableList));
        
        $this->repository->create($tables);
    }
    
    
    public function testUsesProcessorToCreateFixtureContent() : void
    {
        $tables = $this->createMock(Tables::class);
        $data   = [random_int(1, 2) === 2];
        
        $this->reader->method('fetchData')->willReturn($data);
        $this->processor->expects($this->once())->method('createContent')->with($this->equalTo($data));
        
        $this->repository->create($tables);
    }
    
    
    public function testMessagesWriterToImportFixture() : void
    {
        $fixtureData = [random_int(1, 2) === 2];
        $fixture     = $this->createConfiguredMock(
            Fixture::class, [
                              'data' => $fixtureData
                          ]
        );
        
        $this->writer->expects($this->once())->method('import')->with($this->equalTo($fixtureData));
        
        $this->repository->import($fixture);
    }
}